@@ -52,16 +52,15 @@ class Config(object):
         >>> a['overlays']
         '\\nhttp://www.gentoo.org/proj/en/overlays/layman-global.txt'
         >>> sorted(a.keys())
-        ['cache', 'config', 'config_dir', 'local_list', 'make_conf', 'nocheck', 'overlays', 'proxy', 'quietness', 'storage']
+        ['cache', 'config', 'local_list', 'make_conf', 'nocheck', 'overlays', 'proxy', 'quietness', 'storage']
         '''
 
-        self.defaults = {'config_dir': '/etc/layman',
-                         'config'    : '/etc/layman/layman.cfg',
+        self.defaults = {'config'    : '/etc/layman/layman.cfg',
                          'storage'   : '/usr/portage/local/layman',
                          'cache'     : '%(storage)s/cache',
                          'local_list': '%(storage)s/overlays.xml',
                          'make_conf' : '%(storage)s/make.conf',
-                         'nocheck'   : 'no',
+                         'nocheck'   : 'yes',
                          'proxy'     : '',
                          'overlays'  :
                          'http://www.gentoo.org/proj/en/overlays/layman-global.'
@@ -98,6 +97,12 @@ class Config(object):
                          help = 'Update the specified overlay. Use "ALL" as para'
                          'meter to synchronize all overlays')
 
+        group.add_option('-i',
+                         '--info',
+                         action = 'append',
+                         help = 'Display information about the specified overlay'
+                         '.')
+
         group.add_option('-S',
                          '--sync-all',
                          action = 'store_true',
@@ -164,7 +169,8 @@ class Config(object):
         group.add_option('-v',
                          '--verbose',
                          action = 'store_true',
-                         help = 'Increase amount of output.')
+                         help = 'Increase the amount of output and describe the '
+                         'overlays.')
 
         group.add_option('-q',
                          '--quiet',
@@ -176,6 +182,11 @@ class Config(object):
                          'xample if your overlay resides in subversion and the S'
                          'SL certificate of the server needs acceptance.')
 
+        group.add_option('-N',
+                         '--nocolor',
+                         action = 'store_true',
+                         help = 'Remove color codes from the layman output.')
+
         group.add_option('-Q',
                          '--quietness',
                          action = 'store',
@@ -192,6 +203,8 @@ class Config(object):
                          'ssue a warning if description or contact information'
                          ' are missing.')
 
+        self.parser.add_option_group(group)
+
         #-----------------------------------------------------------------
         # Debug Options
 
@@ -204,6 +217,9 @@ class Config(object):
         # handle debugging
         OUT.cli_handle(self.options)
 
+        if self.options.__dict__['nocolor']:
+            OUT.color_off()
+
         # Fetch only an alternate config setting from the options
         if not self.options.__dict__['config'] is None:
             self.defaults['config'] = self.options.__dict__['config']
